#2D plot stuff
library(FactoMineR)
library(plotrix)
library("factoextra")
library(ggplot2)
library(grid)
library(ggrepel)
library(ellipse)

soundGroups=read.csv("allMaster.csv", header = TRUE, row.names = 1, sep = ",")
res.ca = CA(soundGroups, ncp=9)

#colCoord<-res.ca$col$coord
#write.csv(colCoord, file="wordCoord.csv", row.names=TRUE) #<- add word types to this

res.hcpc<-HCPC(res.ca, cluster.CA="rows")

fviz_gg<-fviz_cluster(res.hcpc, ggtheme = theme_bw(), main="", labelsize = 12, ellipse.type = "norm")

title.text<-element_text(size=20, face="bold")
tick.text<-element_text(size=15)


df=read.csv("wordCoord.csv", header = TRUE, sep = ",")
head(df)


df_ell <- data.frame()
for(g in levels(fviz_gg$data$clust)){
df_ell <- rbind(df_ell, cbind(as.data.frame(with(fviz_gg$data[fviz_gg$data$clust==g,], ellipse(cor(x, y), 
                                         scale=c(sd(x),sd(y)), 
                                         centre=c(mean(x),mean(y))))),group=g))
}


p2<-ggplot()+
geom_text_repel(data=df, aes(x=Dim.1, y=Dim.2, label=Word, colour=Type),show.legend = FALSE)+
geom_point(data=df, aes(x=Dim.1, y=Dim.2, colour=Type, shape=Type))+
geom_path(data=df_ell, aes(x=x, y=y, linetype=group), size=1)+
theme_bw()+
labs(x="Dimension 1", y="Dimension 2")+
coord_cartesian(xlim = c(-2, 2),ylim = c(-2, 2)) +
scale_fill_manual(values = c("source"="deepskyblue","signal"="firebrick","affect-judgement"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.2, 0.2), 
	legend.text=tick.text,
	legend.title=tick.text
)		


df=read.csv("vaCorr.csv", header = TRUE, sep = ",") # from Warriner, Kuperman, and Brysbaert 2013
head(df)

p3<-ggplot(df, aes(Dim.1, V))+
geom_text_repel(aes(label=Word),show.legend = FALSE)+
geom_point()+
theme_bw()+
labs(x="Dimension 1", y="Valence")+
geom_smooth(method = "lm", se=FALSE, color="black")+
#coord_cartesian(xlim = c(-1.5, 1.5),ylim = c(1,8)) +
#scale_colour_manual(values = c("source"="deepskyblue","signal"="firebrick","affect-judgement"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.2, 0.2), 
	legend.text=tick.text,
	legend.title=tick.text
)	


p4<-ggplot(df, aes(Dim.2, A))+
geom_text_repel(aes(label=Word),show.legend = FALSE)+
geom_point()+
theme_bw()+
geom_smooth(method = "lm", se=FALSE, color="black")+
labs(x="Dimension 2", y="Arousal")+
#coord_cartesian(xlim = c(-1.5, 1.5),ylim = c(1,8)) +
#scale_colour_manual(values = c("source"="deepskyblue","signal"="firebrick","affect-judgement"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.2, 0.2), 
	legend.text=tick.text,
	legend.title=tick.text
)	


cor.test(df$Dim.1, df$V, type="spearman", alternative="less")
cor.test(df$Dim.2, df$A, type="spearman", alternative="less")

#------------

setEPS()
postscript("dogs_2D.eps", family="Times", width=7, height=21)


grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=3, ncol=1)))

print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
grid.text("A", vp = viewport(layout.pos.row = 1, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p3, vp = viewport(layout.pos.row = 2, layout.pos.col = 1))
grid.text("B", vp = viewport(layout.pos.row = 2, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))
print(p4, vp = viewport(layout.pos.row = 3, layout.pos.col = 1))
grid.text("C", vp = viewport(layout.pos.row = 3, layout.pos.col = 1),y=0.98,x=0.02, gp=gpar(fontsize=15))



dev.off()
